@@ -1,4 +1,5 @@
 """Parser for ThermoPro BLE advertisements."""
+
 from __future__ import annotations
 
 from sensor_state_data import (
@@ -13,11 +14,13 @@ from sensor_state_data import (
     Units,
 )
 
+from .device import ThermoProDevice
 from .parser import ThermoProBluetoothDeviceData
 
-__version__ = "0.4.4"
+__version__ = "0.12.0"
 
 __all__ = [
+    "ThermoProDevice",
     "ThermoProBluetoothDeviceData",
     "BinarySensorDeviceClass",
     "BinarySensorValue",
